-- =============================================
-- SaveToDB Framework for Microsoft SQL Server
-- Version 7.19, March 12, 2018
--
-- This script upgrades SaveToDB Framework 5.x to SaveToDB Framework 7.19
--
-- Copyright 2011-2018 Gartle Technology Corporation
-- =============================================
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     6.2, 2015-12-23
-- Description: SaveToDB Query List view
-- =============================================

ALTER VIEW [dbo01].[viewQueryList]
AS

SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.TABLE_TYPE
    , NULL AS TABLE_CODE
    , COALESCE(q.INSERT_PROCEDURE, i.ROUTINE_SCHEMA + '.' + i.ROUTINE_NAME) AS INSERT_PROCEDURE
    , COALESCE(q.UPDATE_PROCEDURE, u.ROUTINE_SCHEMA + '.' + u.ROUTINE_NAME) AS UPDATE_PROCEDURE
    , COALESCE(q.DELETE_PROCEDURE, d.ROUTINE_SCHEMA + '.' + d.ROUTINE_NAME) AS DELETE_PROCEDURE
    , COALESCE(q.PROCEDURE_TYPE, i.ROUTINE_TYPE) AS PROCEDURE_TYPE
FROM
    (
        SELECT
            t.TABLE_CATALOG
            , t.TABLE_SCHEMA
            , t.TABLE_NAME
            , t.TABLE_TYPE
        FROM
            INFORMATION_SCHEMA.TABLES t
        WHERE
            NOT LEFT(t.TABLE_NAME,3) = 'sys'

        UNION ALL
        SELECT
            r.ROUTINE_CATALOG   AS TABLE_CATALOG
            , r.ROUTINE_SCHEMA  AS TABLE_SCHEMA
            , r.ROUTINE_NAME    AS TABLE_NAME
            , r.ROUTINE_TYPE    AS TABLE_TYPE
        FROM 
            INFORMATION_SCHEMA.ROUTINES r
        WHERE
            NOT LEFT(r.ROUTINE_NAME, 3) = 'sp_'
            AND r.ROUTINE_TYPE = 'PROCEDURE'
            AND NOT r.ROUTINE_NAME LIKE '%_insert'
            AND NOT r.ROUTINE_NAME LIKE '%_update'
            AND NOT r.ROUTINE_NAME LIKE '%_delete'
            AND NOT r.ROUTINE_NAME LIKE '%_merge'
            AND NOT r.ROUTINE_NAME LIKE '%_change'
            AND NOT r.ROUTINE_NAME IN (
                  'uspUpdateColumnTranslation'
                , 'uspUpdateColumnTranslation_Group'
                , 'uspUpdateObjectTranslation'
                , 'uspUpdateObjectTranslationAbsent'
                , 'uspUpdateTableFormat'
            )
    ) t

    LEFT OUTER JOIN INFORMATION_SCHEMA.ROUTINES i ON i.ROUTINE_SCHEMA = t.TABLE_SCHEMA AND i.ROUTINE_NAME = REPLACE(t.TABLE_NAME, '_select', '') + '_insert'
    LEFT OUTER JOIN INFORMATION_SCHEMA.ROUTINES u ON u.ROUTINE_SCHEMA = t.TABLE_SCHEMA AND u.ROUTINE_NAME = REPLACE(t.TABLE_NAME, '_select', '') + '_update'
    LEFT OUTER JOIN INFORMATION_SCHEMA.ROUTINES d ON d.ROUTINE_SCHEMA = t.TABLE_SCHEMA AND d.ROUTINE_NAME = REPLACE(t.TABLE_NAME, '_select', '') + '_delete'
    LEFT OUTER JOIN [dbo01].[QueryList] q ON q.TABLE_SCHEMA = t.TABLE_SCHEMA AND q.TABLE_NAME = t.TABLE_NAME

UNION ALL
SELECT
    q.TABLE_SCHEMA
    , q.TABLE_NAME
    , q.TABLE_TYPE
    , q.TABLE_CODE
    , q.INSERT_PROCEDURE
    , q.UPDATE_PROCEDURE
    , q.DELETE_PROCEDURE
    , q.PROCEDURE_TYPE
FROM
    [dbo01].[QueryList] q
    LEFT OUTER JOIN INFORMATION_SCHEMA.TABLES t ON q.TABLE_SCHEMA = t.TABLE_SCHEMA AND q.TABLE_NAME = t.TABLE_NAME
    LEFT OUTER JOIN INFORMATION_SCHEMA.ROUTINES r ON q.TABLE_SCHEMA = r.ROUTINE_SCHEMA AND q.TABLE_NAME = r.ROUTINE_NAME
WHERE
    q.TABLE_TYPE IN ('CODE', 'HTTP', 'TEXT')
    AND t.TABLE_NAME IS NULL
    AND r.ROUTINE_NAME IS NULL

GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     6.2, 2015-12-23
-- Description: SaveToDB Query List view
-- =============================================

ALTER VIEW [xls01].[viewQueryList]
AS

SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.TABLE_TYPE
    , t.TABLE_CODE
    , t.INSERT_PROCEDURE
    , t.UPDATE_PROCEDURE
    , t.DELETE_PROCEDURE
    , t.PROCEDURE_TYPE
FROM
    [dbo01].[viewQueryList] t
WHERE
    NOT t.TABLE_SCHEMA IN ('etl01', 'dbo01')
    AND NOT t.TABLE_NAME IN (
        'ObjectTranslation'
        , 'ColumnTranslation'
        , 'ParameterValues'
        , 'EventHandlers'
        , 'TableFormats'
        , 'QueryList'

        , 'viewQueryList'
        , 'viewEventHandlers'
        , 'viewColumnTranslation'
        , 'viewObjectTranslation'
        , 'viewParameterValues'
        , 'viewTableFormats'
        )
    AND NOT t.TABLE_NAME LIKE 'viewParameterValues_%'
    AND NOT t.TABLE_NAME LIKE 'uspExcelEvent_%'
    AND NOT t.TABLE_NAME LIKE 'uspParameterValues_%'
    AND NOT t.TABLE_NAME LIKE 'uspValidationList_%'

GO

DELETE FROM [dbo01].[TableFormats] WHERE [TABLE_SCHEMA] = N'dbo01' AND [TABLE_NAME] = N'EventHandlers';
GO

INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'dbo01', N'EventHandlers', '<table name="dbo01.EventHandlers"><columnFormats><column name="" property="ListObjectName" value="EventHandlers_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$7" type="String"/><column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$7" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String"/><column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double"/><column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_NAME" property="Address" value="$E$7" type="String"/><column name="TABLE_NAME" property="ColumnWidth" value="21.71" type="Double"/><column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_NAME" property="Validation.Type" value="6" type="Double"/><column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="COLUMN_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="COLUMN_NAME" property="Address" value="$F$7" type="String"/><column name="COLUMN_NAME" property="ColumnWidth" value="18.57" type="Double"/><column name="COLUMN_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="COLUMN_NAME" property="Validation.Type" value="6" type="Double"/><column name="COLUMN_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="COLUMN_NAME" property="Validation.Operator" value="8" type="Double"/><column name="COLUMN_NAME" property="Validation.Formula1" value="128" type="String"/><column name="COLUMN_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="COLUMN_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="COLUMN_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="EVENT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="EVENT_NAME" property="Address" value="$G$7" type="String"/><column name="EVENT_NAME" property="ColumnWidth" value="15" type="Double"/><column name="EVENT_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="EVENT_NAME" property="Validation.Type" value="3" type="Double"/><column name="EVENT_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="EVENT_NAME" property="Validation.Operator" value="8" type="Double"/><column name="EVENT_NAME" property="Validation.Formula1" value="Actions;Change;ContextMenu;DoubleClick;SelectionChange;DoNotSelect;DoNotSave;DoNotChange;ProtectRows;Formula;FormulaValue;ValidationList;SelectionList" type="String"/><column name="EVENT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="EVENT_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="EVENT_NAME" property="Validation.ErrorMessage" value="The column requires values of the varchar(50) datatype." type="String"/><column name="EVENT_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="EVENT_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_SCHEMA" property="Address" value="$H$7" type="String"/><column name="HANDLER_SCHEMA" property="ColumnWidth" value="19.71" type="Double"/><column name="HANDLER_SCHEMA" property="VerticalAlignment" value="-4160" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="HANDLER_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="HANDLER_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="HANDLER_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_NAME" property="Address" value="$I$7" type="String"/><column name="HANDLER_NAME" property="ColumnWidth" value="57.57" type="Double"/><column name="HANDLER_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="HANDLER_NAME" property="Validation.Type" value="6" type="Double"/><column name="HANDLER_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="HANDLER_NAME" property="Validation.Operator" value="8" type="Double"/><column name="HANDLER_NAME" property="Validation.Formula1" value="128" type="String"/><column name="HANDLER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="HANDLER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="HANDLER_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="HANDLER_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="HANDLER_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="HANDLER_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_TYPE" property="Address" value="$J$7" type="String"/><column name="HANDLER_TYPE" property="ColumnWidth" value="16.29" type="Double"/><column name="HANDLER_TYPE" property="VerticalAlignment" value="-4160" type="Double"/><column name="HANDLER_TYPE" property="Validation.Type" value="3" type="Double"/><column name="HANDLER_TYPE" property="Validation.AlertStyle" value="1" type="Double"/><column name="HANDLER_TYPE" property="Validation.Operator" value="8" type="Double"/><column name="HANDLER_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP;TEXT;MACRO;CMD;REFRESH;MENUSEPARATOR" type="String"/><column name="HANDLER_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="HANDLER_TYPE" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="HANDLER_TYPE" property="Validation.ShowInput" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_CODE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_CODE" property="Address" value="$K$7" type="String"/><column name="HANDLER_CODE" property="ColumnWidth" value="45" type="Double"/><column name="TARGET_WORKSHEET" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TARGET_WORKSHEET" property="Address" value="$L$7" type="String"/><column name="TARGET_WORKSHEET" property="ColumnWidth" value="21.71" type="Double"/><column name="TARGET_WORKSHEET" property="VerticalAlignment" value="-4160" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.Type" value="6" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.AlertStyle" value="1" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.Operator" value="8" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.Formula1" value="128" type="String"/><column name="TARGET_WORKSHEET" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TARGET_WORKSHEET" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TARGET_WORKSHEET" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TARGET_WORKSHEET" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TARGET_WORKSHEET" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TARGET_WORKSHEET" property="Validation.ShowError" value="True" type="Boolean"/><column name="MENU_ORDER" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="MENU_ORDER" property="Address" value="$M$7" type="String"/><column name="MENU_ORDER" property="ColumnWidth" value="15.43" type="Double"/><column name="MENU_ORDER" property="VerticalAlignment" value="-4160" type="Double"/><column name="MENU_ORDER" property="Validation.Type" value="1" type="Double"/><column name="MENU_ORDER" property="Validation.AlertStyle" value="1" type="Double"/><column name="MENU_ORDER" property="Validation.Operator" value="1" type="Double"/><column name="MENU_ORDER" property="Validation.Formula1" value="-2147483648" type="String"/><column name="MENU_ORDER" property="Validation.Formula2" value="2147483647" type="String"/><column name="MENU_ORDER" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="MENU_ORDER" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="MENU_ORDER" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="MENU_ORDER" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="MENU_ORDER" property="Validation.ShowInput" value="True" type="Boolean"/><column name="MENU_ORDER" property="Validation.ShowError" value="True" type="Boolean"/><column name="EDIT_PARAMETERS" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="EDIT_PARAMETERS" property="Address" value="$N$7" type="String"/><column name="EDIT_PARAMETERS" property="ColumnWidth" value="19.57" type="Double"/><column name="EDIT_PARAMETERS" property="VerticalAlignment" value="-4160" type="Double"/><column name="IS_ACTIVE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="IS_ACTIVE" property="Address" value="$O$7" type="String"/><column name="IS_ACTIVE" property="ColumnWidth" value="11.43" type="Double"/><column name="IS_ACTIVE" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$446" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).AppliesTo.Address" value="$D$7:$D$446" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Priority" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$446,$G$7:$G$446,$I$7:$I$446" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Priority" value="3" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="SortFields(1)" property="KeyfieldName" value="TABLE_SCHEMA" type="String"/><column name="SortFields(1)" property="SortOn" value="0" type="Double"/><column name="SortFields(1)" property="Order" value="1" type="Double"/><column name="SortFields(1)" property="DataOption" value="0" type="Double"/><column name="SortFields(2)" property="KeyfieldName" value="TABLE_NAME" type="String"/><column name="SortFields(2)" property="SortOn" value="0" type="Double"/><column name="SortFields(2)" property="Order" value="1" type="Double"/><column name="SortFields(2)" property="DataOption" value="0" type="Double"/><column name="SortFields(3)" property="KeyfieldName" value="EVENT_NAME" type="String"/><column name="SortFields(3)" property="SortOn" value="0" type="Double"/><column name="SortFields(3)" property="Order" value="1" type="Double"/><column name="SortFields(3)" property="DataOption" value="0" type="Double"/><column name="SortFields(4)" property="KeyfieldName" value="MENU_ORDER" type="String"/><column name="SortFields(4)" property="SortOn" value="0" type="Double"/><column name="SortFields(4)" property="Order" value="1" type="Double"/><column name="SortFields(4)" property="DataOption" value="0" type="Double"/><column name="SortFields(5)" property="KeyfieldName" value="HANDLER_NAME" type="String"/><column name="SortFields(5)" property="SortOn" value="0" type="Double"/><column name="SortFields(5)" property="Order" value="1" type="Double"/><column name="SortFields(5)" property="DataOption" value="0" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
GO

-- 7.19

DELETE FROM [dbo01].[TableFormats] WHERE [TABLE_SCHEMA] = N'dbo01' AND [TABLE_NAME] = N'EventHandlers';
GO
DELETE FROM [dbo01].[TableFormats] WHERE [TABLE_SCHEMA] = N'dbo01' AND [TABLE_NAME] = N'ParameterValues';
GO

INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'dbo01', N'EventHandlers', '<table name="dbo01.EventHandlers"><columnFormats><column name="" property="ListObjectName" value="EventHandlers_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$7" type="String"/><column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$7" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String"/><column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double"/><column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_NAME" property="Address" value="$E$7" type="String"/><column name="TABLE_NAME" property="ColumnWidth" value="21.71" type="Double"/><column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_NAME" property="Validation.Type" value="6" type="Double"/><column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="COLUMN_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="COLUMN_NAME" property="Address" value="$F$7" type="String"/><column name="COLUMN_NAME" property="ColumnWidth" value="18.57" type="Double"/><column name="COLUMN_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="COLUMN_NAME" property="Validation.Type" value="6" type="Double"/><column name="COLUMN_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="COLUMN_NAME" property="Validation.Operator" value="8" type="Double"/><column name="COLUMN_NAME" property="Validation.Formula1" value="128" type="String"/><column name="COLUMN_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="COLUMN_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="COLUMN_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="EVENT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="EVENT_NAME" property="Address" value="$G$7" type="String"/><column name="EVENT_NAME" property="ColumnWidth" value="15" type="Double"/><column name="EVENT_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="EVENT_NAME" property="Validation.Type" value="3" type="Double"/><column name="EVENT_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="EVENT_NAME" property="Validation.Operator" value="8" type="Double"/><column name="EVENT_NAME" property="Validation.Formula1" value="Actions;Change;ContextMenu;DoubleClick;SelectionChange;ConvertFormulas;DoNotConvertFormulas;DoNotSelect;DoNotSave;DoNotChange;ProtectRows;Formula;FormulaValue;ValidationList;SelectionList" type="String"/><column name="EVENT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="EVENT_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="EVENT_NAME" property="Validation.ErrorMessage" value="The column requires values of the varchar(50) datatype." type="String"/><column name="EVENT_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="EVENT_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_SCHEMA" property="Address" value="$H$7" type="String"/><column name="HANDLER_SCHEMA" property="ColumnWidth" value="19.71" type="Double"/><column name="HANDLER_SCHEMA" property="VerticalAlignment" value="-4160" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="HANDLER_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="HANDLER_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="HANDLER_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_NAME" property="Address" value="$I$7" type="String"/><column name="HANDLER_NAME" property="ColumnWidth" value="57.57" type="Double"/><column name="HANDLER_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="HANDLER_NAME" property="Validation.Type" value="6" type="Double"/><column name="HANDLER_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="HANDLER_NAME" property="Validation.Operator" value="8" type="Double"/><column name="HANDLER_NAME" property="Validation.Formula1" value="128" type="String"/><column name="HANDLER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="HANDLER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="HANDLER_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="HANDLER_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="HANDLER_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="HANDLER_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_TYPE" property="Address" value="$J$7" type="String"/><column name="HANDLER_TYPE" property="ColumnWidth" value="16.29" type="Double"/><column name="HANDLER_TYPE" property="VerticalAlignment" value="-4160" type="Double"/><column name="HANDLER_TYPE" property="Validation.Type" value="3" type="Double"/><column name="HANDLER_TYPE" property="Validation.AlertStyle" value="1" type="Double"/><column name="HANDLER_TYPE" property="Validation.Operator" value="8" type="Double"/><column name="HANDLER_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP;TEXT;MACRO;CMD;VALUES;RANGE;REFRESH;MENUSEPARATOR" type="String"/><column name="HANDLER_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="HANDLER_TYPE" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="HANDLER_TYPE" property="Validation.ShowInput" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_CODE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_CODE" property="Address" value="$K$7" type="String"/><column name="HANDLER_CODE" property="ColumnWidth" value="45" type="Double"/><column name="TARGET_WORKSHEET" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TARGET_WORKSHEET" property="Address" value="$L$7" type="String"/><column name="TARGET_WORKSHEET" property="ColumnWidth" value="21.71" type="Double"/><column name="TARGET_WORKSHEET" property="VerticalAlignment" value="-4160" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.Type" value="6" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.AlertStyle" value="1" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.Operator" value="8" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.Formula1" value="128" type="String"/><column name="TARGET_WORKSHEET" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TARGET_WORKSHEET" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TARGET_WORKSHEET" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TARGET_WORKSHEET" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TARGET_WORKSHEET" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TARGET_WORKSHEET" property="Validation.ShowError" value="True" type="Boolean"/><column name="MENU_ORDER" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="MENU_ORDER" property="Address" value="$M$7" type="String"/><column name="MENU_ORDER" property="ColumnWidth" value="15.43" type="Double"/><column name="MENU_ORDER" property="VerticalAlignment" value="-4160" type="Double"/><column name="MENU_ORDER" property="Validation.Type" value="1" type="Double"/><column name="MENU_ORDER" property="Validation.AlertStyle" value="1" type="Double"/><column name="MENU_ORDER" property="Validation.Operator" value="1" type="Double"/><column name="MENU_ORDER" property="Validation.Formula1" value="-2147483648" type="String"/><column name="MENU_ORDER" property="Validation.Formula2" value="2147483647" type="String"/><column name="MENU_ORDER" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="MENU_ORDER" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="MENU_ORDER" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="MENU_ORDER" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="MENU_ORDER" property="Validation.ShowInput" value="True" type="Boolean"/><column name="MENU_ORDER" property="Validation.ShowError" value="True" type="Boolean"/><column name="EDIT_PARAMETERS" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="EDIT_PARAMETERS" property="Address" value="$N$7" type="String"/><column name="EDIT_PARAMETERS" property="ColumnWidth" value="19.57" type="Double"/><column name="EDIT_PARAMETERS" property="VerticalAlignment" value="-4160" type="Double"/><column name="IS_ACTIVE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="IS_ACTIVE" property="Address" value="$O$7" type="String"/><column name="IS_ACTIVE" property="ColumnWidth" value="11.43" type="Double"/><column name="IS_ACTIVE" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$446" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).AppliesTo.Address" value="$D$7:$D$446" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Priority" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$446,$G$7:$G$446,$I$7:$I$446" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Priority" value="3" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="SortFields(1)" property="KeyfieldName" value="TABLE_SCHEMA" type="String"/><column name="SortFields(1)" property="SortOn" value="0" type="Double"/><column name="SortFields(1)" property="Order" value="1" type="Double"/><column name="SortFields(1)" property="DataOption" value="0" type="Double"/><column name="SortFields(2)" property="KeyfieldName" value="TABLE_NAME" type="String"/><column name="SortFields(2)" property="SortOn" value="0" type="Double"/><column name="SortFields(2)" property="Order" value="1" type="Double"/><column name="SortFields(2)" property="DataOption" value="0" type="Double"/><column name="SortFields(3)" property="KeyfieldName" value="EVENT_NAME" type="String"/><column name="SortFields(3)" property="SortOn" value="0" type="Double"/><column name="SortFields(3)" property="Order" value="1" type="Double"/><column name="SortFields(3)" property="DataOption" value="0" type="Double"/><column name="SortFields(4)" property="KeyfieldName" value="MENU_ORDER" type="String"/><column name="SortFields(4)" property="SortOn" value="0" type="Double"/><column name="SortFields(4)" property="Order" value="1" type="Double"/><column name="SortFields(4)" property="DataOption" value="0" type="Double"/><column name="SortFields(5)" property="KeyfieldName" value="HANDLER_NAME" type="String"/><column name="SortFields(5)" property="SortOn" value="0" type="Double"/><column name="SortFields(5)" property="Order" value="1" type="Double"/><column name="SortFields(5)" property="DataOption" value="0" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
GO
INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'dbo01', N'ParameterValues', '<table name="dbo01.ParameterValues"><columnFormats><column name="" property="ListObjectName" value="ParameterValues_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$7" type="String"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$7" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String"/><column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_NAME" property="Address" value="$E$7" type="String"/><column name="TABLE_NAME" property="ColumnWidth" value="26.29" type="Double"/><column name="TABLE_NAME" property="Validation.Type" value="6" type="Double"/><column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="PARAMETER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="PARAMETER_NAME" property="Address" value="$F$7" type="String"/><column name="PARAMETER_NAME" property="ColumnWidth" value="20.29" type="Double"/><column name="PARAMETER_NAME" property="Validation.Type" value="6" type="Double"/><column name="PARAMETER_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="PARAMETER_NAME" property="Validation.Operator" value="8" type="Double"/><column name="PARAMETER_NAME" property="Validation.Formula1" value="128" type="String"/><column name="PARAMETER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="PARAMETER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="PARAMETER_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="PARAMETER_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="PARAMETER_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="PARAMETER_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="SELECT_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="SELECT_SCHEMA" property="Address" value="$G$7" type="String"/><column name="SELECT_SCHEMA" property="ColumnWidth" value="17.29" type="Double"/><column name="SELECT_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="SELECT_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="SELECT_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="SELECT_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="SELECT_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="SELECT_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="SELECT_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="SELECT_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="SELECT_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="SELECT_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="SELECT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="SELECT_NAME" property="Address" value="$H$7" type="String"/><column name="SELECT_NAME" property="ColumnWidth" value="34.86" type="Double"/><column name="SELECT_NAME" property="Validation.Type" value="6" type="Double"/><column name="SELECT_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="SELECT_NAME" property="Validation.Operator" value="8" type="Double"/><column name="SELECT_NAME" property="Validation.Formula1" value="128" type="String"/><column name="SELECT_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="SELECT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="SELECT_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="SELECT_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="SELECT_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="SELECT_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="SELECT_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="SELECT_TYPE" property="Address" value="$I$7" type="String"/><column name="SELECT_TYPE" property="ColumnWidth" value="13.86" type="Double"/><column name="SELECT_TYPE" property="Validation.Type" value="3" type="Double"/><column name="SELECT_TYPE" property="Validation.AlertStyle" value="1" type="Double"/><column name="SELECT_TYPE" property="Validation.Operator" value="8" type="Double"/><column name="SELECT_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP;VALUES;RANGE" type="String"/><column name="SELECT_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="SELECT_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="SELECT_TYPE" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="SELECT_TYPE" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="SELECT_TYPE" property="Validation.ShowInput" value="True" type="Boolean"/><column name="SELECT_TYPE" property="Validation.ShowError" value="True" type="Boolean"/><column name="SELECT_CODE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="SELECT_CODE" property="Address" value="$J$7" type="String"/><column name="SELECT_CODE" property="ColumnWidth" value="70.71" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$63" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).AppliesTo.Address" value="$D$7:$D$63" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Priority" value="7" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double"/><column name="SELECT_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$G$7:$G$63,$I$7:$I$63" type="String"/><column name="SELECT_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="SELECT_SCHEMA" property="FormatConditions(1).Priority" value="4" type="Double"/><column name="SELECT_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(G7)" type="String"/><column name="SELECT_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="SELECT_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
GO

ALTER TABLE [dbo01].[EventHandlers] ALTER COLUMN [HANDLER_NAME] nvarchar(128) NULL;
GO

UPDATE [dbo01].[EventHandlers] SET [HANDLER_TYPE] = N'VALUES', [HANDLER_CODE] = N'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList' WHERE [TABLE_SCHEMA] = N'dbo01' AND [TABLE_NAME] = N'EventHandlers'         AND [COLUMN_NAME] = N'EVENT_NAME'       AND [EVENT_NAME] = N'ValidationList';
UPDATE [dbo01].[EventHandlers] SET [HANDLER_TYPE] = N'VALUES', [HANDLER_CODE] = N'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR'                                                                                                   WHERE [TABLE_SCHEMA] = N'dbo01' AND [TABLE_NAME] = N'EventHandlers'         AND [COLUMN_NAME] = N'HANDLER_TYPE'     AND [EVENT_NAME] = N'ValidationList';
UPDATE [dbo01].[EventHandlers] SET [HANDLER_TYPE] = N'VALUES', [HANDLER_CODE] = N'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,VALUES,RANGE'                                                                                                                                        WHERE [TABLE_SCHEMA] = N'dbo01' AND [TABLE_NAME] = N'ParameterValues'       AND [COLUMN_NAME] = N'SELECT_TYPE'      AND [EVENT_NAME] = N'ValidationList';
UPDATE [dbo01].[EventHandlers] SET [HANDLER_TYPE] = N'VALUES', [HANDLER_CODE] = N'TABLE,VIEW,PROCEDURE,CODE,HTTP,TEXT'                                                                                                                                                         WHERE [TABLE_SCHEMA] = N'dbo01' AND [TABLE_NAME] = N'QueryList'             AND [COLUMN_NAME] = N'TABLE_TYPE'       AND [EVENT_NAME] = N'ValidationList';
UPDATE [dbo01].[EventHandlers] SET [HANDLER_TYPE] = N'VALUES', [HANDLER_CODE] = N'TABLE,PROCEDURE,CODE,MERGE'                                                                                                                                                                  WHERE [TABLE_SCHEMA] = N'dbo01' AND [TABLE_NAME] = N'QueryList'             AND [COLUMN_NAME] = N'PROCEDURE_TYPE'   AND [EVENT_NAME] = N'ValidationList';

UPDATE [dbo01].[EventHandlers] SET [HANDLER_TYPE] = N'VALUES', [HANDLER_CODE] = N'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList' WHERE [TABLE_SCHEMA] = N'xls01' AND [TABLE_NAME] = N'viewEventHandlers'     AND [COLUMN_NAME] = N'EVENT_NAME'       AND [EVENT_NAME] = N'ValidationList';
UPDATE [dbo01].[EventHandlers] SET [HANDLER_TYPE] = N'VALUES', [HANDLER_CODE] = N'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR'                                                                                                   WHERE [TABLE_SCHEMA] = N'xls01' AND [TABLE_NAME] = N'viewEventHandlers'     AND [COLUMN_NAME] = N'HANDLER_TYPE'     AND [EVENT_NAME] = N'ValidationList';
UPDATE [dbo01].[EventHandlers] SET [HANDLER_TYPE] = N'VALUES', [HANDLER_CODE] = N'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,VALUES,RANGE'                                                                                                                                        WHERE [TABLE_SCHEMA] = N'xls01' AND [TABLE_NAME] = N'viewParameterValues'   AND [COLUMN_NAME] = N'SELECT_TYPE'      AND [EVENT_NAME] = N'ValidationList';
UPDATE [dbo01].[EventHandlers] SET [HANDLER_TYPE] = N'VALUES', [HANDLER_CODE] = N'TABLE,VIEW,PROCEDURE,CODE,HTTP,TEXT'                                                                                                                                                         WHERE [TABLE_SCHEMA] = N'xls01' AND [TABLE_NAME] = N'viewQueryList'         AND [COLUMN_NAME] = N'TABLE_TYPE'       AND [EVENT_NAME] = N'ValidationList';
UPDATE [dbo01].[EventHandlers] SET [HANDLER_TYPE] = N'VALUES', [HANDLER_CODE] = N'TABLE,PROCEDURE,CODE,MERGE'                                                                                                                                                                  WHERE [TABLE_SCHEMA] = N'xls01' AND [TABLE_NAME] = N'viewQueryList'         AND [COLUMN_NAME] = N'PROCEDURE_TYPE'   AND [EVENT_NAME] = N'ValidationList';

INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'dbo01' AS [TABLE_SCHEMA], N'EventHandlers'          AS [TABLE_NAME], N'HANDLER_CODE'    AS [COLUMN_NAME], N'DoNotConvertFormulas' AS [EVENT_NAME], NULL AS [HANDLER_TYPE], NULL AS [HANDLER_CODE]) s LEFT OUTER JOIN [dbo01].[EventHandlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'xls01' AS [TABLE_SCHEMA], N'viewEventHandlers'      AS [TABLE_NAME], N'HANDLER_CODE'    AS [COLUMN_NAME], N'DoNotConvertFormulas' AS [EVENT_NAME], NULL AS [HANDLER_TYPE], NULL AS [HANDLER_CODE]) s LEFT OUTER JOIN [dbo01].[EventHandlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;

INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'dbo01' AS [TABLE_SCHEMA], N'EventHandlers'          AS [TABLE_NAME], N'EVENT_NAME'      AS [COLUMN_NAME], N'ValidationList' AS [EVENT_NAME], N'VALUES' AS [HANDLER_TYPE], N'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList'    AS [HANDLER_CODE]) s LEFT OUTER JOIN [dbo01].[EventHandlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'dbo01' AS [TABLE_SCHEMA], N'EventHandlers'          AS [TABLE_NAME], N'HANDLER_TYPE'    AS [COLUMN_NAME], N'ValidationList' AS [EVENT_NAME], N'VALUES' AS [HANDLER_TYPE], N'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR'                                                                                                      AS [HANDLER_CODE]) s LEFT OUTER JOIN [dbo01].[EventHandlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'dbo01' AS [TABLE_SCHEMA], N'ParameterValues'        AS [TABLE_NAME], N'SELECT_TYPE'     AS [COLUMN_NAME], N'ValidationList' AS [EVENT_NAME], N'VALUES' AS [HANDLER_TYPE], N'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,VALUES,RANGE'                                                                                                                                           AS [HANDLER_CODE]) s LEFT OUTER JOIN [dbo01].[EventHandlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'dbo01' AS [TABLE_SCHEMA], N'QueryList'              AS [TABLE_NAME], N'TABLE_TYPE'      AS [COLUMN_NAME], N'ValidationList' AS [EVENT_NAME], N'VALUES' AS [HANDLER_TYPE], N'TABLE,VIEW,PROCEDURE,CODE,HTTP,TEXT'                                                                                                                                                            AS [HANDLER_CODE]) s LEFT OUTER JOIN [dbo01].[EventHandlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'dbo01' AS [TABLE_SCHEMA], N'QueryList'              AS [TABLE_NAME], N'PROCEDURE_TYPE'  AS [COLUMN_NAME], N'ValidationList' AS [EVENT_NAME], N'VALUES' AS [HANDLER_TYPE], N'TABLE,PROCEDURE,CODE,MERGE'                                                                                                                                                                     AS [HANDLER_CODE]) s LEFT OUTER JOIN [dbo01].[EventHandlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;

INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'xls01' AS [TABLE_SCHEMA], N'viewEventHandlers'      AS [TABLE_NAME], N'EVENT_NAME'      AS [COLUMN_NAME], N'ValidationList' AS [EVENT_NAME], N'VALUES' AS [HANDLER_TYPE], N'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList'    AS [HANDLER_CODE]) s LEFT OUTER JOIN [dbo01].[EventHandlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'xls01' AS [TABLE_SCHEMA], N'viewEventHandlers'      AS [TABLE_NAME], N'HANDLER_TYPE'    AS [COLUMN_NAME], N'ValidationList' AS [EVENT_NAME], N'VALUES' AS [HANDLER_TYPE], N'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR'                                                                                                      AS [HANDLER_CODE]) s LEFT OUTER JOIN [dbo01].[EventHandlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'xls01' AS [TABLE_SCHEMA], N'viewParameterValues'    AS [TABLE_NAME], N'SELECT_TYPE'     AS [COLUMN_NAME], N'ValidationList' AS [EVENT_NAME], N'VALUES' AS [HANDLER_TYPE], N'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,VALUES,RANGE'                                                                                                                                           AS [HANDLER_CODE]) s LEFT OUTER JOIN [dbo01].[EventHandlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'xls01' AS [TABLE_SCHEMA], N'viewQueryList'          AS [TABLE_NAME], N'TABLE_TYPE'      AS [COLUMN_NAME], N'ValidationList' AS [EVENT_NAME], N'VALUES' AS [HANDLER_TYPE], N'TABLE,VIEW,PROCEDURE,CODE,HTTP,TEXT'                                                                                                                                                            AS [HANDLER_CODE]) s LEFT OUTER JOIN [dbo01].[EventHandlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'xls01' AS [TABLE_SCHEMA], N'viewQueryList'          AS [TABLE_NAME], N'PROCEDURE_TYPE'  AS [COLUMN_NAME], N'ValidationList' AS [EVENT_NAME], N'VALUES' AS [HANDLER_TYPE], N'TABLE,PROCEDURE,CODE,MERGE'                                                                                                                                                                     AS [HANDLER_CODE]) s LEFT OUTER JOIN [dbo01].[EventHandlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;
GO
